@@ -56,7 +56,7 @@ static sw_param_range max_interruption_range = {
 static sw_param_spec param_specs[] = {
   {
     N_("Select regions above threshold"),
-    N_("Whether to select those regions lying above a given threshhold"
+    N_("Whether to select those regions lying above a given threshold "
        "or below it."),
     SWEEP_TYPE_BOOL,
     SW_PARAM_CONSTRAINED_NOT,
