@@ -18,6 +18,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdio.h>
 #include <gtk/gtk.h>
 
@@ -36,6 +40,10 @@
 #include "../pixmaps/zoom_in_mask.xbm"
 #include "../pixmaps/zoom_out.xbm"
 #include "../pixmaps/zoom_out_mask.xbm"
+#include "../pixmaps/cursor-openhand.xbm"
+#include "../pixmaps/cursor-openhand_mask.xbm"
+#include "../pixmaps/cursor-closedhand.xbm"
+#include "../pixmaps/cursor-closedhand_mask.xbm"
 
 GdkCursor * sweep_cursors[SWEEP_CURSOR_MAX];
 
@@ -96,21 +104,25 @@ init_cursors (void)
   sweep_cursors[SWEEP_CURSOR_PENCIL] = gdk_cursor_new (GDK_PENCIL);
   sweep_cursors[SWEEP_CURSOR_NOISE] = gdk_cursor_new (GDK_SPRAYCAN);
 
+
   create_bitmap_and_mask_from_xpm (&bitmap, &mask, horiz_xpm);
   
   sweep_cursors[SWEEP_CURSOR_HORIZ] =
     gdk_cursor_new_from_pixmap (bitmap, mask, &white, &black, 8, 8);
 
+
   create_bitmap_and_mask_from_xpm (&bitmap, &mask, horiz_plus_xpm);
   
   sweep_cursors[SWEEP_CURSOR_HORIZ_PLUS] =
     gdk_cursor_new_from_pixmap (bitmap, mask, &white, &black, 8, 8);
 
+
   create_bitmap_and_mask_from_xpm (&bitmap, &mask, horiz_minus_xpm);
   
   sweep_cursors[SWEEP_CURSOR_HORIZ_MINUS] =
     gdk_cursor_new_from_pixmap (bitmap, mask, &white, &black, 8, 8);
 
+
   bitmap =
     gdk_bitmap_create_from_data (NULL, zoom_in_bits,
 				 zoom_in_width, zoom_in_height);
@@ -134,10 +146,10 @@ init_cursors (void)
 				zoom_out_x_hot, zoom_out_y_hot);
 
   bitmap =
-    gdk_bitmap_create_from_data (NULL, needle_bits,
+    gdk_bitmap_create_from_data (NULL, (const gchar *) needle_bits,
 				 needle_width, needle_height);
   mask =
-    gdk_bitmap_create_from_data (NULL, needle_mask_bits,
+    gdk_bitmap_create_from_data (NULL, (const gchar *) needle_mask_bits,
 				 needle_mask_width, needle_mask_height);
 
   sweep_cursors[SWEEP_CURSOR_NEEDLE] =
@@ -146,10 +158,10 @@ init_cursors (void)
 
 
   bitmap =
-    gdk_bitmap_create_from_data (NULL, hand_bits,
+    gdk_bitmap_create_from_data (NULL, (const gchar *) hand_bits,
 				 hand_width, hand_height);
   mask =
-    gdk_bitmap_create_from_data (NULL, hand_mask_bits,
+    gdk_bitmap_create_from_data (NULL, (const gchar *) hand_mask_bits,
 				 hand_mask_width, hand_mask_height);
 
   sweep_cursors[SWEEP_CURSOR_MOVE] =
@@ -157,4 +169,28 @@ init_cursors (void)
 				hand_x_hot, hand_y_hot);
 
 
+  bitmap =
+    gdk_bitmap_create_from_data (NULL, (const gchar *) cursor_openhand_bits,
+				 cursor_openhand_width, cursor_openhand_height);
+  mask =
+    gdk_bitmap_create_from_data (NULL, (const gchar *) cursor_openhand_mask_bits,
+				 cursor_openhand_mask_width, cursor_openhand_mask_height);
+
+  sweep_cursors[SWEEP_CURSOR_HAND_OPEN] =
+    gdk_cursor_new_from_pixmap (bitmap, mask, &black, &white,
+				cursor_openhand_x_hot, cursor_openhand_y_hot);
+
+
+  bitmap =
+    gdk_bitmap_create_from_data (NULL, (const gchar *) cursor_closedhand_bits,
+				 cursor_closedhand_width, cursor_closedhand_height);
+  mask =
+    gdk_bitmap_create_from_data (NULL, (const gchar *) cursor_closedhand_mask_bits,
+				 cursor_closedhand_mask_width, cursor_closedhand_mask_height);
+
+  sweep_cursors[SWEEP_CURSOR_HAND_CLOSE] =
+    gdk_cursor_new_from_pixmap (bitmap, mask, &black, &white,
+				cursor_closedhand_x_hot, cursor_closedhand_y_hot);
+
+
 }
