@@ -18,9 +18,19 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
 
+#include <unistd.h>
+#include <sys/mman.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+
 #include <sweep/sweep_i18n.h>
 #include <sweep/sweep_types.h>
 #include <sweep/sweep_typeconvert.h>
@@ -36,6 +46,97 @@
 
 sw_edit_buffer * ebuf = NULL;
 
+void *
+sweep_large_alloc_data (size_t len, void * data, int prot)
+{
+  void * ptr;
+
+#if HAVE_MMAP
+  FILE * f;
+  int fd;
+
+  if ((f = tmpfile ()) == NULL) {
+    perror ("tmpfile failed in sweep_large_alloc_data");
+    return NULL;
+  }
+
+  if (fwrite (data, len, 1, f) != 1) {
+    perror ("short fwrite in sweep_large_alloc_data");
+    return NULL;
+  }
+
+  if (fseek (f, 0, SEEK_SET) == -1) {
+    perror ("fseek failed in sweep_large_alloc_data");
+    return NULL;
+  }
+
+  if ((fd = fileno (f)) == -1) {
+    perror ("fileno failed in sweep_large_alloc_data");
+    return NULL;
+  }
+
+  if ((ptr = mmap (NULL, len, prot, MAP_PRIVATE, fd, 0)) == MAP_FAILED) {
+    perror ("mmap failed in sweep_large_alloc_data");
+    return NULL;
+  }
+#else
+  ptr = g_malloc (len);
+
+  memcpy (ptr, data, len);
+#endif
+
+  return ptr;
+}
+
+void *
+sweep_large_alloc_zero (size_t len, int prot)
+{
+  void * ptr;
+
+#if HAVE_MMAP
+  int fd;
+
+  if ((fd = open ("/dev/zero", O_RDWR)) == -1) {
+    perror ("open failed in sweep_large_alloc_zero");
+    return NULL;
+  }
+
+  if (lseek (fd, len+1, SEEK_SET) == (off_t)-1) {
+    perror ("lseek failed in sweep_large_alloc_zero");
+    return NULL;
+  }
+
+  if (write (fd, "", 1) == -1) {
+    perror ("write failed in sweep_large_alloc_zero");
+    return NULL;
+  }
+
+  if (lseek (fd, 0, SEEK_SET) == (off_t)-1) {
+    perror ("lseek failed in sweep_large_alloc_zero");
+    return NULL;
+  }
+
+  if ((ptr = mmap (NULL, len, prot, MAP_PRIVATE, fd, 0)) == MAP_FAILED) {
+    perror ("mmap failed in sweep_large_alloc_zero");
+    return NULL;
+  }
+#else
+  ptr = g_malloc0 (len);
+#endif
+
+  return ptr;
+}
+
+void
+sweep_large_free (void * ptr, size_t len)
+{
+#if HAVE_MMAP
+  if (munmap (ptr, len) == -1)
+    perror ("munmap failed in sweep_large_free()");
+#else
+  g_free (ptr);
+#endif
+}
 
 static sw_edit_region *
 edit_region_new (sw_format * format, sw_framecount_t start,
@@ -50,9 +151,7 @@ edit_region_new (sw_format * format, sw_framecount_t start,
   er->end = end;
 
   len = frames_to_bytes (format, end-start);
-  er->data = g_malloc (len);
-
-  memcpy (er->data, data, len);
+  er->data = sweep_large_alloc_data (len, data, PROT_READ);
 
   return er;
 }
@@ -88,6 +187,7 @@ edit_buffer_new (sw_format * format)
   eb = g_malloc0 (sizeof(sw_edit_buffer));
   eb->format = format_copy (format);
   eb->regions = NULL;
+  eb->refcount = 1;
 
   return eb;
 }
@@ -112,29 +212,44 @@ edit_buffer_copy (sw_edit_buffer * oeb)
   return eb;
 }
 
+sw_edit_buffer *
+edit_buffer_ref (sw_edit_buffer * eb)
+{
+  eb->refcount++;
+  return eb;
+}
+
 static void
 edit_buffer_clear (sw_edit_buffer * eb)
 {
   GList * gl;
   sw_edit_region * er;
+  size_t len;
 
   if (!eb) return;
 
-  g_free (eb->format);
-
   for (gl = eb->regions; gl; gl = gl->next) {
     er = (sw_edit_region *)gl->data;
-    if (er) g_free (er->data);
+    if (er) {
+      len = frames_to_bytes (eb->format, er->end - er->start);
+      sweep_large_free (er->data, len);
+    }
   }
   g_list_free (eb->regions);
 
+  g_free (eb->format);
+
   eb->format = NULL;
   eb->regions = NULL;
+  eb->refcount = 0;
 }
 
 void
 edit_buffer_destroy (sw_edit_buffer * eb)
 {
+  eb->refcount--;
+  if (eb->refcount > 0) return;
+
   edit_buffer_clear (eb);
   g_free (eb);
 }
@@ -144,8 +259,8 @@ ebuf_clear (void)
 {
   if (!ebuf) return;
 
-  edit_buffer_clear (ebuf);
-  g_free (ebuf);
+  edit_buffer_destroy (ebuf);
+
   ebuf = NULL;
 }
 
@@ -165,6 +280,32 @@ edit_buffer_length (sw_edit_buffer * eb)
   return length;
 }
 
+static sw_framecount_t
+edit_buffer_width (sw_edit_buffer * eb)
+{
+  GList * gl;
+  sw_edit_region * er;
+  sw_framecount_t start, end;
+
+  if (eb == NULL) return 0;
+
+  if ((gl = eb->regions) == NULL) return 0;
+  er = (sw_edit_region *)gl->data;
+  start = er->start;
+
+  gl = g_list_last (eb->regions);
+  er = (sw_edit_region *)gl->data;
+  end = er->end;
+  
+  return (end - start);
+}
+
+sw_framecount_t
+clipboard_width (void)
+{
+  return edit_buffer_width (ebuf);
+}
+
 static sw_edit_buffer *
 edit_buffer_from_sounddata_sels (sw_sounddata * sounddata, GList * sels)
 {
@@ -204,6 +345,29 @@ edit_buffer_from_sample (sw_sample * sample)
   return edit_buffer_from_sounddata (sample->sounddata);
 }
 
+static GList *
+sels_from_edit_buffer_offset (sw_edit_buffer * eb, sw_framecount_t offset)
+{
+  GList * gl, * sels = NULL;
+  sw_edit_region * er;
+  sw_framecount_t start;
+
+  gl = eb->regions;
+  if (!gl) return NULL;
+
+  er = (sw_edit_region *)gl->data;
+  start = er->start;
+
+  for (gl = eb->regions; gl; gl = gl->next) {
+    er = (sw_edit_region *)gl->data;
+
+    sels = sels_add_selection_1 (sels, er->start - start + offset,
+				 er->end - start + offset);
+  }
+
+  return sels;
+}
+
 static sw_sample *
 sample_from_edit_buffer (sw_edit_buffer * eb)
 {
@@ -267,6 +431,22 @@ head_dec_if_within (sw_head * head, sw_framecount_t lower,
   g_mutex_unlock (head->head_mutex);
 }
 
+static void
+head_inc_if_gt (sw_head * head, sw_framecount_t lower, sw_framecount_t amount)
+{
+  if (head == NULL) return;
+
+  g_mutex_lock (head->head_mutex);
+
+  if (head->stop_offset > lower)
+    head->stop_offset += amount;
+
+  if (head->offset > lower)
+    head->offset += amount;
+
+  g_mutex_unlock (head->head_mutex);
+}
+
 static void
 head_set_if_within (sw_head * head, sw_framecount_t lower,
 		    sw_framecount_t upper, sw_framecount_t value)
@@ -441,88 +621,97 @@ sounddata_set_sel_from_eb (sw_sounddata * sounddata, sw_edit_buffer * eb)
 }
 
 /* returns new sounddata */
-static sw_sounddata *
-splice_in_eb_data (sw_sounddata * sounddata, sw_edit_buffer * eb)
+static sw_sample *
+splice_in_eb_data (sw_sample * sample, sw_edit_buffer * eb)
 {
+  sw_sounddata * sounddata = sample->sounddata;
   sw_format * f = sounddata->format;
   gint length;
   GList * gl;
   sw_edit_region * er;
-  sw_framecount_t prev_end = 0;
-  sw_sounddata * out;
+  sw_framecount_t prev_start = 0;
+  sw_framecount_t er_width;
   gpointer di, d;
   sw_framecount_t len;
 
   if (!eb) {
-    return sounddata;
+    return sample;
   }
 
-  length = sounddata->nr_frames + edit_buffer_length (eb);
-
-#if 0
-  d = g_realloc (sounddata->data, length);
-  sounddata->data = d;
-
-  di = d;
-
-  /* XXX: implement with realloc! */
+  g_mutex_lock (sample->ops_mutex);
 
   /* in reverse ... decrementing d, di; just like paste at only crunchy */
 
-#else
-  di = sounddata->data;
+  length = sounddata->nr_frames + edit_buffer_length (eb);
 
-  out = sounddata_new_empty (f->channels, f->rate, length);
+  d = g_realloc (sounddata->data, frames_to_bytes (f, length));
+  sounddata->data = d;
 
-  d = out->data;
+  /* set di to point to the end of the original data */
+  di = d + frames_to_bytes (f, sounddata->nr_frames);
 
-  gl = eb->regions;
+  /* set d to point to end of newly realloc'd buffer */
+  d += frames_to_bytes (f, length);
+
+  prev_start = length;
+
+  gl = g_list_last (eb->regions);
   er = (sw_edit_region *)gl->data;
-  if (er->start <= 0) {
+  if (er->start >= sounddata->nr_frames) {
     len = frames_to_bytes (f, er->end - er->start);
+    d -= len;
     memcpy (d, er->data, len);
-    d += len;
-    prev_end = er->end;
-    gl = gl->next;
+    prev_start = er->start;
+    gl = gl->prev;
   }
 
-  for (; gl; gl = gl->next) {
+  for (; gl; gl = gl->prev) {
     er = (sw_edit_region *)gl->data;
 
-    /* Copy sample data in */
-    len = frames_to_bytes (f, er->start - prev_end);
-    memcpy (d, di, len);
-    di += len;
-    d += len;
+    /* Move the sample data in */
+    len = frames_to_bytes (f, prev_start - er->end);
+    di -= len;
+    d -= len;
+    memmove (d, di, len);
 
     /* Copy edit_region data in */
     len = frames_to_bytes (f, er->end - er->start);
+    d -= len;
     memcpy (d, er->data, len);
-    d += len;
-
-    prev_end = er->end;
+    prev_start = er->start;
   }
 
-  /* Copy remaining sample data in, if any */
-  if (prev_end < length) {
-    len = frames_to_bytes (f, length - prev_end);
-    memcpy (d, di, len);
+  /* The head of the sounddata remains intact */
+
+  /* Move offset markers */
+
+  for (gl = eb->regions; gl; gl = gl->next) {
+    er = (sw_edit_region *)gl->data;
+
+    er_width = er->end - er->start;
+
+    if (sample->user_offset > er->end)
+      sample->user_offset += er_width;
+
+    head_inc_if_gt (sample->play_head, er->end, er_width);
+    head_inc_if_gt (sample->rec_head, er->end, er_width);
   }
-  
-  return out;
-#endif
+
+  sounddata->nr_frames = length;
+
+  g_mutex_unlock (sample->ops_mutex);
+
+  return sample;
 }
 
 /* returns new sounddata */
-sw_sounddata *
-splice_in_eb (sw_sounddata * sounddata, sw_edit_buffer * eb)
+sw_sample *
+splice_in_eb (sw_sample * sample, sw_edit_buffer * eb)
 {
-  sw_sounddata * out;
-  
-  out = splice_in_eb_data (sounddata, eb);
-  sounddata_set_sel_from_eb (out, eb);
+  splice_in_eb_data (sample, eb);
+  sounddata_set_sel_from_eb (sample->sounddata, eb);
 
-  return out;
+  return sample;
 }
 
 /* modifies sounddata */
@@ -813,7 +1002,6 @@ paste_insert (sw_sample * sample, sw_edit_buffer * eb,
 {
   sw_sounddata * sounddata = sample->sounddata;
   sw_format * f = sounddata->format;
-  /*sw_framecount_t paste_offset = 0;*/
   sw_framecount_t paste_delta = 0, len;
   sw_framecount_t length, paste_length, sel_length = 0;
   GList * gl;
@@ -863,18 +1051,19 @@ paste_insert (sw_sample * sample, sw_edit_buffer * eb,
 			     paste_offset + paste_length);
 
   /* Move offset markers */
-  if (sample->user_offset >= paste_offset)
+
+  if (sample->user_offset > paste_offset)
     sample->user_offset += sel_length;
 
-  if (sample->play_head->offset >= paste_offset)
+  if (sample->play_head->offset > paste_offset)
     sample->play_head->offset += sel_length;
-  if (sample->play_head->stop_offset >= paste_offset)
+  if (sample->play_head->stop_offset > paste_offset)
     sample->play_head->stop_offset += sel_length;
 
   if (sample->rec_head) {
-    if (sample->rec_head->offset >= paste_offset)
+    if (sample->rec_head->offset > paste_offset)
       sample->rec_head->offset += sel_length;
-    if (sample->rec_head->stop_offset >= paste_offset)
+    if (sample->rec_head->stop_offset > paste_offset)
       sample->rec_head->stop_offset += sel_length;
   }
 
@@ -926,7 +1115,9 @@ paste_mix (sw_sample * sample, sw_edit_buffer * eb,
 
   gboolean active = TRUE;
 
+#ifdef DEBUG
   g_print ("paste_mix: src_gain %f, dest_gain %f\n", src_gain, dest_gain);
+#endif
 
   if (eb == NULL || eb->regions == NULL) return sample;
 
@@ -972,7 +1163,6 @@ paste_mix (sw_sample * sample, sw_edit_buffer * eb,
 	percent = run_total / (eb_total/100);
 	sample_set_progress_percent (sample, percent);
 	
-#define DEBUG
 #ifdef DEBUG
 	g_print ("completed %d / %d frames, %d%%\n", run_total, eb_total,
 		 percent);
@@ -987,6 +1177,101 @@ paste_mix (sw_sample * sample, sw_edit_buffer * eb,
   return sample;
 }
 
+/* Modifies sample */
+static sw_sample *
+paste_xfade (sw_sample * sample, sw_edit_buffer * eb,
+	     sw_framecount_t paste_offset,
+	     gdouble src_gain_start, gdouble src_gain_end,
+	     gdouble dest_gain_start, gdouble dest_gain_end)
+{
+  sw_format * f = sample->sounddata->format;
+  sw_framecount_t length, eb_delta;
+  GList * gl;
+  sw_edit_region * er;
+  sw_audio_t * d, * e;
+  sw_framecount_t offset, remaining, n, i, j, k;
+  sw_framecount_t run_total, eb_total;
+  gint percent;
+
+  gdouble src_gain, dest_gain;
+  gdouble src_gain_delta, dest_gain_delta;
+
+  gboolean active = TRUE;
+
+#ifdef DEBUG
+  g_print ("paste_xfade: src: %f -> %f\tdest: %f -> %f\n",
+	   src_gain_start, src_gain_end, dest_gain_start, dest_gain_end);
+#endif
+
+  if (eb == NULL || eb->regions == NULL) return sample;
+
+  length = sample->sounddata->nr_frames;
+
+  run_total = 0;
+  eb_total = edit_buffer_length (eb);
+
+  eb_delta = ((sw_edit_region *)eb->regions->data)->start;
+
+  src_gain = src_gain_start;
+  dest_gain = dest_gain_start;
+
+  src_gain_delta = (src_gain_end - src_gain_start) / (gdouble)eb_total;
+  dest_gain_delta = (dest_gain_end - dest_gain_start) / (gdouble)eb_total;
+
+  for (gl = eb->regions; active && gl; gl = gl->next) {
+    er = (sw_edit_region *)gl->data;
+
+    if (er->start > length) break;
+    
+    d = sample->sounddata->data +
+      frames_to_bytes (f, er->start - eb_delta + paste_offset);
+    e = er->data;
+    
+    offset = 0;
+    remaining = MIN(er->end, length) - er->start;
+
+    while (active && remaining > 0) {
+      g_mutex_lock (sample->ops_mutex);
+      
+      if (sample->edit_state == SWEEP_EDIT_STATE_CANCEL) {
+	active = FALSE;
+      } else {
+	
+	n = MIN(remaining, 1024);
+
+	k = 0;
+	for (i = 0; i < n; i++) {
+	  for (j = 0; j < f->channels; j++) {
+	    d[k] = d[k] * dest_gain + e[k] * src_gain;
+	    k++;
+	  }
+	  src_gain += src_gain_delta;
+	  dest_gain += dest_gain_delta;
+	}
+	
+	remaining -= n;
+	offset += n;
+	
+	d += n * f->channels;
+	e += n * f->channels;
+	
+	run_total += n;
+	percent = run_total / (eb_total/100);
+	sample_set_progress_percent (sample, percent);
+	
+#ifdef DEBUG
+	g_print ("completed %d / %d frames, %d%%\n", run_total, eb_total,
+		 percent);
+#endif
+      }
+      
+      g_mutex_unlock (sample->ops_mutex);
+    }
+    
+  }
+  
+  return sample;
+}
 
 static void
 do_copy_thread (sw_op_instance * inst)
@@ -1042,7 +1327,8 @@ do_cut_thread (sw_op_instance * inst)
 
   ebuf_clear ();
 
-  ebuf = edit_buffer_copy (eb);
+  /*ebuf = edit_buffer_copy (eb);*/
+  ebuf = edit_buffer_ref (eb);
 
   splice_out_sel (sample);
 
@@ -1212,7 +1498,7 @@ do_crop (sw_sample * sample)
   schedule_operation (sample, _("Crop"), &crop_op, NULL);
 }
 
-
+#if 0
 static sw_operation paste_in_op = {
   SWEEP_EDIT_MODE_ALLOC,
   (SweepCallback)do_paste_in,
@@ -1233,7 +1519,8 @@ do_paste_in (sw_sample * in, sw_sample ** out)
   if (ebuf == NULL) return NULL;
 
   inst = sw_op_instance_new (in, "Paste in", &paste_in_op);
-  eb = edit_buffer_copy (ebuf);
+  /*eb = edit_buffer_copy (ebuf);*/
+  eb = edit_buffer_ref (ebuf);
 
   (*out)->sounddata = splice_in_eb (in->sounddata, ebuf);
 
@@ -1244,6 +1531,7 @@ do_paste_in (sw_sample * in, sw_sample ** out)
 
   return inst;
 }
+#endif
 
 static void
 do_paste_insert_thread (sw_op_instance * inst)
@@ -1257,7 +1545,8 @@ do_paste_insert_thread (sw_op_instance * inst)
   if (!format_equal (ebuf->format, sample->sounddata->format))
     goto incompatible;
 
-  eb1 = edit_buffer_copy (ebuf);
+  /*eb1 = edit_buffer_copy (ebuf);*/
+  eb1 = edit_buffer_ref (ebuf);
 
   inst->undo_data = splice_data_new (eb1, sample->sounddata->sels);
   inst->redo_data = NULL;
@@ -1301,32 +1590,50 @@ do_paste_insert (sw_sample * sample)
   schedule_operation (sample, _("Paste insert"), &paste_insert_op, NULL);
 }
 
+typedef struct {
+  gdouble src_gain;
+  gdouble dest_gain;
+} paste_mix_op_data;
+
 static void
 do_paste_mix_thread (sw_op_instance * inst)
 {
   sw_sample * sample = inst->sample;
+  paste_mix_op_data * pd = (paste_mix_op_data *)inst->do_data;
   sw_sounddata * out;
+  GList * old_sels, * sels;
   sw_edit_buffer * eb1, *eb2;
+  gdouble src_gain, dest_gain;
+
+  src_gain = pd->src_gain;
+  dest_gain = pd->dest_gain;
+  g_free (pd);
 
   if (ebuf == NULL) goto noop;
 
   if (!format_equal (ebuf->format, sample->sounddata->format))
     goto incompatible;
 
-  eb1 = edit_buffer_copy (ebuf);
+  old_sels = sels_copy (sample->sounddata->sels);
+  sels = sels_from_edit_buffer_offset (ebuf, sample->user_offset);
+  sample_set_selection (sample, sels);
 
-  inst->undo_data = splice_data_new (eb1, sample->sounddata->sels);
+  eb1 = edit_buffer_from_sounddata (sample->sounddata);
+
+  inst->undo_data = splice_data_new (eb1, old_sels);
   inst->redo_data = NULL;
   set_active_op (sample, inst);
 
-  paste_mix (sample, ebuf, sample->user_offset, 0.5, 0.5);
+  paste_mix (sample, ebuf, sample->user_offset, src_gain, dest_gain);
 
   if (sample->edit_state == SWEEP_EDIT_STATE_BUSY) {
     out = sample->sounddata;
     eb2 = edit_buffer_from_sounddata (out);
-    inst->redo_data = splice_data_new (eb2, NULL);
+    inst->redo_data = splice_data_new (eb2, sels);
 
     register_operation (sample, inst);
+  } else {
+    sample_set_selection (sample, old_sels);
   }
 
   return;
@@ -1344,41 +1651,113 @@ static sw_operation paste_mix_op = {
   SWEEP_EDIT_MODE_FILTER,
   (SweepCallback)do_paste_mix_thread,
   (SweepFunction)NULL,
-  (SweepCallback)undo_by_paste_over,
-  (SweepFunction)paste_over_data_destroy,
-  (SweepCallback)redo_by_paste_over,
-  (SweepFunction)paste_over_data_destroy
+  (SweepCallback)undo_by_splice_over,
+  (SweepFunction)splice_data_destroy,
+  (SweepCallback)redo_by_splice_over,
+  (SweepFunction)splice_data_destroy
 };
 
-
 void
-do_paste_mix (sw_sample * sample)
+do_paste_mix (sw_sample * sample, gdouble src_gain, gdouble dest_gain)
 {
-  schedule_operation (sample, _("Paste mix"), &paste_mix_op, NULL);
+  paste_mix_op_data * pd;
+
+  pd = g_malloc (sizeof(paste_mix_op_data));
+  pd->src_gain = src_gain;
+  pd->dest_gain = dest_gain;
+
+  schedule_operation (sample, _("Paste mix"), &paste_mix_op, pd);
 }
 
+typedef struct {
+  gdouble src_gain_start;
+  gdouble src_gain_end;
+  gdouble dest_gain_start;
+  gdouble dest_gain_end;
+} paste_xfade_op_data;
+
 static void
 do_paste_xfade_thread (sw_op_instance * inst)
 {
-  /*  sw_sample * sample = inst->sample;*/
+  sw_sample * sample = inst->sample;
+  paste_xfade_op_data * pd = (paste_xfade_op_data *)inst->do_data;
+  sw_sounddata * out;
+  GList * old_sels, * sels;
+  sw_edit_buffer * eb1, *eb2;
+  gdouble src_gain_start, src_gain_end, dest_gain_start, dest_gain_end;
+
+  src_gain_start = pd->src_gain_start;
+  src_gain_end = pd->src_gain_end;
+  dest_gain_start = pd->dest_gain_start;
+  dest_gain_end = pd->dest_gain_end;
+  g_free (pd);
+
+  if (ebuf == NULL) goto noop;
+
+  if (!format_equal (ebuf->format, sample->sounddata->format))
+    goto incompatible;
+
+  old_sels = sels_copy (sample->sounddata->sels);
+  sels = sels_from_edit_buffer_offset (ebuf, sample->user_offset);
+  sample_set_selection (sample, sels);
+
+  eb1 = edit_buffer_from_sounddata (sample->sounddata);
+
+  inst->undo_data = splice_data_new (eb1, old_sels);
+  inst->redo_data = NULL;
+  set_active_op (sample, inst);
+
+  paste_xfade (sample, ebuf, sample->user_offset, src_gain_start,
+	       src_gain_end, dest_gain_start, dest_gain_end);
+
+  if (sample->edit_state == SWEEP_EDIT_STATE_BUSY) {
+    out = sample->sounddata;
+    eb2 = edit_buffer_from_sounddata (out);
+    inst->redo_data = splice_data_new (eb2, sels);
+
+    register_operation (sample, inst);
+  } else {
+    sample_set_selection (sample, old_sels);
+  }
+
+  return;
+
+ noop:
+  sample_set_tmp_message (sample, _("Clipboard empty"));
+  return;
+
+ incompatible:
+  sample_set_tmp_message (sample, _("Clipboard data has incompatible format"));
+  return;
 }
 
 static sw_operation paste_xfade_op = {
   SWEEP_EDIT_MODE_FILTER,
   (SweepCallback)do_paste_xfade_thread,
   (SweepFunction)NULL,
-  (SweepCallback)undo_by_paste_over,
-  (SweepFunction)paste_over_data_destroy,
-  (SweepCallback)redo_by_paste_over,
-  (SweepFunction)paste_over_data_destroy
+  (SweepCallback)undo_by_splice_over,
+  (SweepFunction)splice_data_destroy,
+  (SweepCallback)redo_by_splice_over,
+  (SweepFunction)splice_data_destroy
 };
 
 void
-do_paste_xfade (sw_sample * sample)
+do_paste_xfade (sw_sample * sample, gdouble src_gain_start,
+		gdouble src_gain_end, gdouble dest_gain_start,
+		gdouble dest_gain_end)
 {
-  schedule_operation (sample, _("Paste xfade"), &paste_xfade_op, NULL);
+  paste_xfade_op_data * pd;
+
+  pd = g_malloc (sizeof(paste_xfade_op_data));
+  pd->src_gain_start = src_gain_start;
+  pd->src_gain_end = src_gain_end;
+  pd->dest_gain_start = dest_gain_start;
+  pd->dest_gain_end = dest_gain_end;
+
+  schedule_operation (sample, _("Paste xfade"), &paste_xfade_op, pd);
 }
 
+#if 0
 static sw_operation paste_over_op = {
   SWEEP_EDIT_MODE_FILTER,
   (SweepCallback)NULL,
@@ -1410,6 +1789,7 @@ do_paste_over (sw_sample * in, sw_sample **out)
 
   return inst;
 }
+#endif
 
 sw_sample *
 do_paste_as_new (void)
