@@ -18,8 +18,14 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <stdio.h>
 #include <string.h>
+#include <math.h>
+
 #include <sweep/sweep_i18n.h>
 #include <sweep/sweep_types.h>
 #include "sweep_app.h"
@@ -108,8 +114,8 @@ snprint_param (gchar * s, gint n, sw_param_type type, sw_param p)
 {
   switch (type) {
   case SWEEP_TYPE_BOOL:
-    if (p.b) snprintf (s, n, "TRUE");
-    else snprintf (s, n, "FALSE");
+    if (p.b) snprintf (s, n, _("TRUE"));
+    else snprintf (s, n, _("FALSE"));
     break;
   case SWEEP_TYPE_INT:
     snprintf (s, n, "%d", p.i);
@@ -379,6 +385,7 @@ create_param_set_table (sw_ps_adjuster * ps)
 
   GtkObject * adj;
   gfloat value, lower, upper, step_inc, page_inc, page_size;
+  gint digits = 1; /* nr. of decimal places to show on hscale */
 
   table = gtk_table_new (proc->nr_params, 2, FALSE);
 
@@ -387,7 +394,7 @@ create_param_set_table (sw_ps_adjuster * ps)
 
     if (pspec->type == SWEEP_TYPE_BOOL) {
 
-      checkbutton = gtk_check_button_new_with_label (pspec->name);
+      checkbutton = gtk_check_button_new_with_label (_(pspec->name));
       gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 2, i, i+1,
 			GTK_FILL, GTK_FILL, 0, 0);
 
@@ -407,10 +414,10 @@ create_param_set_table (sw_ps_adjuster * ps)
 
       hbox = gtk_hbox_new (FALSE, 0);
       gtk_table_attach (GTK_TABLE (table), hbox, 0, 1, i, i+1,
-			GTK_FILL|GTK_EXPAND, GTK_SHRINK, 4, 4);
+			GTK_FILL|GTK_SHRINK, GTK_SHRINK, 4, 4);
       gtk_widget_show (hbox);
 
-      label = gtk_label_new (pspec->name);
+      label = gtk_label_new (_(pspec->name));
       gtk_box_pack_end (GTK_BOX(hbox), label, FALSE, FALSE, 4);
       gtk_widget_show (label);
 
@@ -441,8 +448,8 @@ create_param_set_table (sw_ps_adjuster * ps)
 	  gtk_menu_append (GTK_MENU(menu), menuitem);
 	  gtk_widget_show (menuitem);
 
-          gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-            GTK_SIGNAL_FUNC(param_list_set_known_cb), &plsk[j]);
+          g_signal_connect (G_OBJECT(menuitem), "activate",
+            G_CALLBACK(param_list_set_known_cb), &plsk[j]);
 
 	  if (!param_cmp (pspec->type, pspec->constraint.list[j+1], pset[i])) {
 	    gtk_option_menu_set_history (GTK_OPTION_MENU(optionmenu), j);
@@ -457,7 +464,7 @@ create_param_set_table (sw_ps_adjuster * ps)
 
 #define ADJUSTER_NUMERIC(T, DIGITS) \
                                                                            \
-	value = (gfloat) pset[i].T;                                    \
+	value = (gfloat) pset[i].T;                                        \
                                                                            \
         if (pspec->constraint_type == SW_PARAM_CONSTRAINED_NOT) {          \
           valid = 0;                                                       \
@@ -466,19 +473,19 @@ create_param_set_table (sw_ps_adjuster * ps)
         }                                                                  \
 	                                                                   \
 	if (valid & SW_RANGE_LOWER_BOUND_VALID) {                          \
-	  lower = (gfloat) pspec->constraint.range->lower.T;           \
+	  lower = (gfloat) pspec->constraint.range->lower.T;               \
 	} else {                                                           \
 	  lower = G_MINFLOAT;                                              \
 	}                                                                  \
 	                                                                   \
 	if (valid & SW_RANGE_UPPER_BOUND_VALID) {                          \
-	  upper = (gfloat) pspec->constraint.range->upper.T;           \
+	  upper = (gfloat) pspec->constraint.range->upper.T;               \
 	} else {                                                           \
 	  upper = G_MAXFLOAT;                                              \
 	}                                                                  \
 	                                                                   \
 	if (valid & SW_RANGE_STEP_VALID) {                                 \
-	  step_inc = (gfloat) pspec->constraint.range->step.T;         \
+	  step_inc = (gfloat) pspec->constraint.range->step.T;             \
 	} else if (lower != G_MINFLOAT && upper != G_MAXFLOAT) {           \
           step_inc = (upper - lower) / 100.0;                              \
         } else {                                                           \
@@ -486,14 +493,20 @@ create_param_set_table (sw_ps_adjuster * ps)
 	}                                                                  \
 	page_inc = step_inc;                                               \
 	page_size = step_inc;                                              \
+        if (step_inc < 1.0)                                                \
+          digits = - (gint)ceil(log10((double)step_inc));                  \
+        else                                                               \
+          digits = 1;                                                      \
                                                                            \
 	adj = gtk_adjustment_new (value, lower, upper, step_inc,           \
 				  page_inc, page_size);                    \
                                                                            \
 	if ( (valid & SW_RANGE_LOWER_BOUND_VALID) &&                       \
 	     (valid & SW_RANGE_UPPER_BOUND_VALID)) {                       \
+          GTK_ADJUSTMENT(adj)->upper += step_inc;                          \
 	  num_widget = gtk_hscale_new (GTK_ADJUSTMENT(adj));               \
-          gtk_widget_set_usize (num_widget, 75, -1);                       \
+          gtk_scale_set_digits (GTK_SCALE(num_widget), digits);            \
+          gtk_widget_set_size_request (num_widget, 75, -1);                       \
 	  gtk_table_attach (GTK_TABLE (table), num_widget, 1, 2, i, i+1,   \
 			    GTK_FILL|GTK_EXPAND, GTK_SHRINK, 0, 0);        \
 	} else {                                                           \
@@ -504,7 +517,7 @@ create_param_set_table (sw_ps_adjuster * ps)
           gtk_spin_button_set_numeric (GTK_SPIN_BUTTON(num_widget), TRUE); \
           gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON(num_widget),  \
                                          TRUE);                            \
-          gtk_widget_set_usize (num_widget, 75, -1);                       \
+          gtk_widget_set_size_request (num_widget, 75, -1);                       \
 	  gtk_table_attach (GTK_TABLE (table), num_widget, 1, 2, i, i+1,   \
 			    GTK_FILL|GTK_EXPAND, GTK_SHRINK, 0, 0);        \
 	}                                                                  \
@@ -556,9 +569,6 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
 			   sw_param_set pset)
 {
   sw_ps_adjuster * ps;
-
-  GtkStyle * style;
-
   GtkWidget * window;
   GtkWidget * main_vbox;
   GtkWidget * pixmap;
@@ -578,7 +588,6 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
 
 #ifdef _USE_TEXT
   GtkWidget * text;
-  GdkFont * font;
 
 #define BUF_LEN 1024
   gchar buf[BUF_LEN];
@@ -587,13 +596,13 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
 #endif /* _USE_TEXT */
 
   window = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW(window), proc->name);
+  gtk_window_set_title (GTK_WINDOW(window), _(proc->name));
   /*  gtk_container_border_width (GTK_CONTAINER (window), 8);*/
 
   ps = ps_adjuster_new (proc, view, pset, window);
 
-  gtk_signal_connect (GTK_OBJECT(window), "destroy",
-		      GTK_SIGNAL_FUNC(param_set_cancel_cb), ps);
+  g_signal_connect (G_OBJECT(window), "destroy",
+		      G_CALLBACK(param_set_cancel_cb), ps);
 
 #ifdef _USE_TEXT
   hbox = gtk_hbox_new (FALSE, 0);
@@ -603,7 +612,7 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   text = gtk_text_new (NULL, NULL);
   gtk_text_set_editable (GTK_TEXT (text), FALSE);
   gtk_text_set_word_wrap (GTK_TEXT (text), FALSE);
-  gtk_widget_set_usize (text, 320, -1);
+  gtk_widget_set_size_request (text, 320, -1);
   gtk_box_pack_start (GTK_BOX (hbox), text, FALSE, FALSE, 0);
   gtk_widget_show (text);
 
@@ -643,27 +652,29 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   if (proc->name != NULL) {
 
 #ifdef _USE_TEXT
-    font =
-      gdk_font_load("-Adobe-Helvetica-Medium-R-Normal--*-140-*-*-*-*-*-*");
-
-    n = snprintf (buf, BUF_LEN, "%s\n\n", proc->name);
-
-    gtk_text_insert (GTK_TEXT (text), font, NULL, NULL, buf, n);
-
+/*
+ * font =
+ * gdk_font_load("-Adobe-Helvetica-Medium-R-Normal--*-140-*-*-*-*-*-*");
+ *
+ * n = snprintf (buf, BUF_LEN, "%s\n\n", _(proc->name));
+ * gtk_text_insert (GTK_TEXT (text), font, NULL, NULL, buf, n);
+ */
 #else
 
-    style = gtk_style_new ();
-    gdk_font_unref (style->font);
-    style->font =
-      gdk_font_load("-adobe-helvetica-medium-r-normal-*-*-180-*-*-*-*-*-*");
-    gtk_widget_push_style (style);
-
-    label = gtk_label_new (proc->name);
+/* pangoise?
+ *  
+ * style = gtk_style_new ();
+ * gdk_font_unref (style->font);
+ * style->font =
+ * gdk_font_load("-adobe-helvetica-medium-r-normal-*-*-180-*-*-*-*-*-*");
+ * gtk_widget_push_style (style);
+ */
+    label = gtk_label_new (_(proc->name));
     gtk_misc_set_padding (GTK_MISC (label), 10, 10);
     gtk_box_pack_start (GTK_BOX(vbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
 
-    gtk_widget_pop_style ();
+/*  gtk_widget_pop_style ();*/
 
 #endif
   }
@@ -672,7 +683,7 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   n = 0;
 
   if (proc->description != NULL) {
-    n = snprintf (buf, BUF_LEN, "%s\n\n", proc->description);
+    n = snprintf (buf, BUF_LEN, "%s\n\n", _(proc->description));
   }
 
   if (proc->author != NULL) {
@@ -696,7 +707,7 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
 
 #else
   if (proc->description != NULL) {
-    label = gtk_label_new (proc->description);
+    label = gtk_label_new (_(proc->description));
     gtk_box_pack_start (GTK_BOX(vbox), label, FALSE, FALSE, 0);
     gtk_widget_show (label);
   }
@@ -724,7 +735,7 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   gtk_box_pack_start (GTK_BOX(main_vbox), hbox, TRUE, TRUE, 8);
   gtk_widget_show (hbox);
 
-  frame = gtk_frame_new ("Parameters");
+  frame = gtk_frame_new (_("Parameters"));
   gtk_box_pack_start (GTK_BOX(hbox), frame, TRUE, TRUE, 8);
   gtk_widget_show (frame);
 
@@ -736,11 +747,11 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   button = gtk_button_new_with_label (_("Defaults"));
   gtk_box_pack_start (GTK_BOX(vbox), button, FALSE, FALSE, 8);
   gtk_widget_show (button);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC (param_set_suggest_cb), ps);
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK (param_set_suggest_cb), ps);
 
   scrolled = gtk_scrolled_window_new (NULL, NULL);
-  gtk_widget_set_usize (scrolled, -1, 240);
+  gtk_widget_set_size_request (scrolled, -1, 240);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
 				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
   gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 8);
@@ -755,7 +766,7 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   ps->table = table;
 
 #if 0
-  frame = gtk_frame_new ("Preview");
+  frame = gtk_frame_new (_("Preview"));
   gtk_box_pack_start (GTK_BOX(hbox), frame, TRUE, TRUE, 8);
   gtk_widget_show (frame);
 
@@ -770,8 +781,8 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG(window)->action_area), ok_button,
 		      TRUE, TRUE, 0);
   gtk_widget_show (ok_button);
-  gtk_signal_connect (GTK_OBJECT(ok_button), "clicked",
-		      GTK_SIGNAL_FUNC (param_set_apply_cb), ps);
+  g_signal_connect (G_OBJECT(ok_button), "clicked",
+		      G_CALLBACK (param_set_apply_cb), ps);
   
 
   button = gtk_button_new_with_label (_("Cancel"));
@@ -779,8 +790,8 @@ create_param_set_adjuster (sw_procedure * proc, sw_view * view,
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG(window)->action_area), button,
 		      TRUE, TRUE, 0);
   gtk_widget_show (button);
-  gtk_signal_connect (GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC (param_set_cancel_cb), ps);
+  g_signal_connect (G_OBJECT(button), "clicked",
+		      G_CALLBACK (param_set_cancel_cb), ps);
 
   gtk_widget_grab_default (ok_button);
 
