@@ -24,10 +24,10 @@
 #include "sweep_app.h"
 
 void
-play_view_all (sw_view * view);
+init_playback (void);
 
 void
-play_preview_cursor (sw_view * view);
+play_view_all (sw_view * view);
 
 void
 play_preroll (sw_view * view);
@@ -47,6 +47,9 @@ stop_all_playback (void);
 void
 sample_play (sw_sample * sample);
 
+void
+sample_update_device (sw_sample * sample);
+
 void
 pause_playback (sw_sample * s);
 
