@@ -111,6 +111,7 @@ extern GdkCursor * sweep_cursors[];
 
 #define MARCH_INTERVAL 300
 #define PULSE_INTERVAL 450
+#define HAND_SCROLL_INTERVAL 50
 
 extern sw_view * last_tmp_view;
 
@@ -199,6 +200,7 @@ enum {
   SELECTING_PLAYMARKER,
   SELECTING_PENCIL,
   SELECTING_NOISE,
+  SELECTING_HAND,
 };
 
 enum {
@@ -227,7 +229,7 @@ static gchar * selection_mode_names[SELECTION_MODE_MAX] = {
 
 static guint sample_display_signals[LAST_SIGNAL] = { 0 };
 
-static gchar sel_dash_list[2] = { 4, 4 }; /* Equivalent to GDK's default
+static gint8 sel_dash_list[2] = { 4, 4 }; /* Equivalent to GDK's default
 					  *  dash list.
 					  */
 
@@ -486,6 +488,9 @@ sample_display_set_default_cursor (SampleDisplay * s)
   case TOOL_NOISE:
     cursor = sweep_cursors[SWEEP_CURSOR_NOISE];
     break;
+  case TOOL_HAND:
+    cursor = sweep_cursors[SWEEP_CURSOR_HAND_OPEN];
+    break;
   default:
     cursor = NULL;
     break;
@@ -633,14 +638,17 @@ sample_display_init_display (SampleDisplay *s,
   s->width = w;
   s->height = h;
 
-  if(s->backing_pixmap) {
-    g_object_unref(s->backing_pixmap);
-  }
   window = GTK_WIDGET(s)->window;
   visual = gdk_rgb_get_visual();
 
+#if DOUBLE_BUFFER
+  if(s->backing_pixmap) {
+    g_object_unref(s->backing_pixmap);
+  }
   s->backing_pixmap = gdk_pixmap_new (GTK_WIDGET(s)->window,  
                                       w, h, visual->depth);
+#endif
+
 }
 
 static void
@@ -1617,6 +1625,37 @@ sample_display_expose (GtkWidget *widget,
   return FALSE;
 }
 
+static gint
+sample_display_hand_scroll (SampleDisplay * s)
+{
+  gint new_win_start, win_length;
+  gfloat step;
+  
+  win_length = s->view->end - s->view->start;
+
+  step = win_length * 1.0 / s->width;
+
+  new_win_start = s->view->start + s->hand_scroll_delta * step;
+  
+  new_win_start = CLAMP(new_win_start, 0,
+			s->view->sample->sounddata->nr_frames -
+			(s->view->end - s->view->start));
+
+  if(new_win_start != s->view->start) {
+    sample_display_set_window (s,
+			       new_win_start,
+			       new_win_start + win_length);
+  } else {
+	  s->hand_scroll_delta = 0;
+  }
+/*
+  g_print ("s->delta: %i new_win_start: %i\n", s->hand_scroll_delta, new_win_start);
+*/
+  s->hand_scroll_delta *= 0.98;
+
+  return (s->hand_scroll_delta != 0);
+}
+
 static gint
 sample_display_scroll_left (gpointer data)
 {
@@ -1876,6 +1915,52 @@ sample_display_handle_pencil_motion (SampleDisplay * s, int x, int y)
   sample_refresh_views (sample);
 }
 
+static void
+sample_display_handle_hand_motion (SampleDisplay * s, int x, int y)
+{
+  gdouble move, vstart, vend;
+  gdouble step = (gdouble)(s->view->end - s->view->start) / ((gdouble)s->width);
+  GtkAdjustment * adj = GTK_ADJUSTMENT(s->view->adj);
+  gint delta;
+
+  delta = s->view->hand_offset - x;
+
+  s->hand_scroll_delta *= 0.9;
+
+  if (abs (delta) > abs (s->hand_scroll_delta))
+	  s->hand_scroll_delta = delta;
+  
+  if (s->view->hand_offset != x){
+    move = s->view->hand_offset - x;
+    move *= step;
+
+    vstart = s->view->start + move;
+    vend = s->view->end + move;
+
+    if (vstart < 0){
+	vstart = 0;
+	vend = adj->page_size;
+    }
+    if (vend > s->view->sample->sounddata->nr_frames){
+	vstart = s->view->sample->sounddata->nr_frames - adj->page_size; 
+	vend = s->view->sample->sounddata->nr_frames;
+    }
+    
+	vstart = ceil(vstart + (move < 0 ? 0.5 : -0.5));
+    vend = ceil(vend + (move < 0 ? 0.5 : -0.5));
+
+    if (s->view->start != vstart && s->view->end != vend)
+	    s->view->hand_offset = x;
+
+    s->view->start = vstart;
+    s->view->end = vend;
+
+    view_refresh_display(s->view);
+
+    gtk_adjustment_set_value( GTK_ADJUSTMENT(s->view->adj), vstart);
+  }
+}
+
 static void
 sample_display_handle_noise_motion (SampleDisplay * s, int x, int y)
 {
@@ -2094,11 +2179,12 @@ sample_display_button_press (GtkWidget      *widget,
       s->selecting == SELECTING_PLAYMARKER) {
     gdk_window_get_pointer (event->window, &x, &y, &state);
     sample_display_handle_playmarker_motion (s, x, y);
-  } else if(s->selecting && event->button != last_button) {
+  } else 
+  if(s->selecting && event->button != last_button) {
     /* Cancel the current operation if a different button is pressed. */
     sample_display_clear_sel (s);
-  } else if (last_tmp_view && last_tmp_view != s->view &&
-	     event->button != last_button) {
+  } else 
+  if (last_tmp_view && last_tmp_view != s->view && event->button != last_button) {
     view_clear_last_tmp_view ();
   } else {
     last_button = event->button;
@@ -2158,14 +2244,25 @@ sample_display_button_press (GtkWidget      *widget,
 	}
 #endif
 	break;
+      case TOOL_HAND:
+	    s->selecting = SELECTING_HAND;
+	    s->view->hand_offset = x;
+	    s->hand_scroll_delta = 0;
+	    if (s->hand_scroll_tag){
+		   g_source_remove (s->hand_scroll_tag);
+		   s->hand_scroll_tag = 0;
+	    }
+	    SET_CURSOR(widget, HAND_CLOSE);
+	    sample_display_handle_hand_motion (s, x, y);
+	break;
       case TOOL_ZOOM:
-	o = XPOS_TO_OFFSET(x);
-	view_center_on (s->view, o);
-	if (state & GDK_SHIFT_MASK) {
-	  view_zoom_out (s->view, 2.0);
-	} else {
-	  view_zoom_in (s->view, 2.0);
-	}
+	    o = XPOS_TO_OFFSET(x);
+	    view_center_on (s->view, o);
+	    if (state & GDK_SHIFT_MASK) {
+	      view_zoom_out (s->view, 2.0);
+	    } else {
+	      view_zoom_in (s->view, 2.0);
+	    }
 	break;
       case TOOL_PENCIL:
 	s->selecting = SELECTING_PENCIL;
@@ -2293,6 +2390,14 @@ sample_display_button_release (GtkWidget      *widget,
     break;
   case TOOL_SCRUB:
     if (s->meta_down) return TRUE;
+    break;
+  case TOOL_HAND:
+    s->view->hand_offset = -1;
+
+    s->hand_scroll_tag = g_timeout_add (HAND_SCROLL_INTERVAL,
+		    (GSourceFunc)sample_display_hand_scroll,
+		    s);
+
     break;
   case TOOL_MOVE:
     break;
@@ -2350,6 +2455,9 @@ sample_display_motion_notify (GtkWidget *widget,
       case SELECTING_PLAYMARKER:
 	sample_display_handle_playmarker_motion (s, x, y);
 	break;
+      case SELECTING_HAND:
+	    sample_display_handle_hand_motion (s, x, y);
+	    break;
       case SELECTING_PENCIL:
 	sample_display_handle_pencil_motion (s, x, y);
 	break;
@@ -2866,6 +2974,7 @@ sample_display_init (SampleDisplay *s)
   s->marching = FALSE;
   s->pulsing_tag = 0;
   s->pulse = FALSE;
+  s->hand_scroll_tag = 0;
   s->mouse_x = 0;
   s->mouse_offset = 0;
   s->scroll_left_tag = 0;
