@@ -25,7 +25,7 @@
 #include "sweep_app.h"
 
 void
-create_sample_new_dialog_defaults (void);
+create_sample_new_dialog_defaults (char * pathname);
 
 void
 create_sample_new_dialog_like (sw_sample * s);
@@ -39,6 +39,15 @@ sample_remove_view (sw_sample * s, sw_view * v);
 gint
 sample_clear_tmp_message (gpointer data);
 
+void
+sample_set_monitor (sw_sample * s, gboolean monitor);
+
+void
+sample_set_offset_next_bound_left (sw_sample * s);
+
+void
+sample_set_offset_next_bound_right (sw_sample * s);
+
 void
 sample_refresh_rec_marker (sw_sample * s);
 
