@@ -44,6 +44,7 @@ typedef enum {
   TOOL_SCRUB,
   TOOL_PENCIL,
   TOOL_NOISE,
+  TOOL_HAND
 } sw_tool_t;
 
 /* View colors */
@@ -86,6 +87,8 @@ struct _sw_view {
 
   gboolean following; /* whether or not to follow playmarker */
 
+  gint hand_offset;
+
   GtkWidget * window;
   GtkWidget * time_ruler;
   GtkWidget * scrollbar;
