@@ -91,6 +91,7 @@ sounddata_new_empty(gint nr_channels, gint sample_rate, gint sample_length)
 
   s->sels = NULL;
   s->sels_mutex = g_mutex_new();
+  s->data_mutex = g_mutex_new();
 
   return s;
 }
@@ -98,6 +99,14 @@ sounddata_new_empty(gint nr_channels, gint sample_rate, gint sample_length)
 void
 sounddata_clear_selection (sw_sounddata * sounddata)
 {
+  GList * gl;
+  sw_sel * sel;
+
+  for (gl = sounddata->sels; gl; gl = gl->next){
+          sel = (sw_sel*)gl->data;
+          sel_free(sel);
+  }
+
   g_list_free(sounddata->sels);
 
   sounddata->sels = NULL;
@@ -119,6 +128,7 @@ sounddata_destroy (sw_sounddata * sounddata)
 #endif
     sounddata_clear_selection (sounddata);
     g_free (sounddata);
+    g_mutex_free(sounddata->data_mutex);
   }
 }
 
@@ -242,7 +252,7 @@ sounddata_normalise_selection (sw_sounddata * sounddata)
   }
 
   /* Clear the old selection */
-  g_list_free (sounddata->sels);
+  sounddata_clear_selection (sounddata);
 
   /* Set the newly created (normalised) selection */
   sounddata->sels = nsels;
